@@ -151,7 +151,7 @@ def cy_clean(target_files:[str] = None, keep_c_files:bool=False):
             dstfilename=os.path.join(built_file_folder, pyd_file),
             overwrite=True
         )
-def cy_interface(target_files:[str] = None):
+def cy_interface(target_files:[str] = None, encoding:str='UTF-8'):
     """ Creates .pyi interface files from the provided target_files """
 
 
@@ -168,5 +168,11 @@ def cy_interface(target_files:[str] = None):
         pyi_fullpath = f"{os.path.splitext(pyx_fullpath)[0]}.pyi"
         logger.debug(msg=f"Creating .pyi for {pyx_fullpath}")
 
-        pyigenerator.read_write_pyx_to_pyi(target_pyx_path=pyx_fullpath, target_pyi_path=pyi_fullpath)
+        with open(pyx_fullpath, mode='r', encoding=encoding) as open_pyx:
+            pyi_content:[str] = pyigenerator.pyx_to_pyi(open_pyx=open_pyx)
+
+        with open(pyi_fullpath, 'w') as pyi_out:
+            pyi_out.writelines(pyi_content)
+
+
 
